from typing import Union

import pint

METER = 'meter'
CENTIMETER = 'centimeter'
MILLIMETER = 'millimeter'
KILOMETER = 'kilometer'
INCH = 'inch'
HAND = 'hand'
FOOT = 'foot'
YARD = 'yard'
MILE = 'mile'
LIGHT_YEAR = 'light_year'
ASTRONOMICAL_UNIT = 'astronomical_unit'
PARSEC = 'parsec'
NAUTICAL_MILE = 'nautical_mile'
ANGSTROM = 'angstrom'
MICRON = 'micron'
PLANCK_LENGTH = 'planck_length'


def convert(
        distance: Union[int, float],
        unit: Union[
            'METER',
            'CENTIMETER',
            'MILLIMETER',
            'KILOMETER',
            'INCH',
            'HAND',
            'FOOT',
            'YARD',
            'MILE',
            'LIGHT_YEAR',
            'ASTRONOMICAL_UNIT',
            'PARSEC',
            'NAUTICAL_MILE',
            'ANGSTROM',
            'MICRON',
            'PLANCK_LENGTH'
        ],
        unit_to: Union[
            'METER',
            'CENTIMETER',
            'MILLIMETER',
            'KILOMETER',
            'INCH',
            'HAND',
            'FOOT',
            'YARD',
            'MILE',
            'LIGHT_YEAR',
            'ASTRONOMICAL_UNIT',
            'PARSEC',
            'NAUTICAL_MILE',
            'ANGSTROM',
            'MICRON',
            'PLANCK_LENGTH'
        ]
) -> str:
    """
    Converts a distance unit to other different unit

    :param distance:
    :param unit:
    :param unit_to:
    :return:
    """

    return pint.Quantity(distance, unit).to(unit_to)



from typing import Union

import pint

SECONDS = "seconds"
MINUTES = "minutes"
HOURS = "hours"
DAYS = "days"
WEEKS = "weeks"
FORTNIGHTS = "fortnights"
YEARS = "years"
MONTHS = "months"
CENTURIES = "centuries"
MILLENNIUMS = "millenniums"


def convert(
        time: Union[int, float],
        unit: Union[
            SECONDS,
            MINUTES,
            HOURS,
            DAYS,
            WEEKS,
            FORTNIGHTS,
            YEARS,
            MONTHS,
            CENTURIES,
            MILLENNIUMS
        ],
        unit_to: Union[
            SECONDS,
            MINUTES,
            HOURS,
            DAYS,
            WEEKS,
            FORTNIGHTS,
            YEARS,
            MONTHS,
            CENTURIES,
            MILLENNIUMS
        ]
) -> str:
    """
    Converts a time unit to other different unit

    :param time:
    :param unit:
    :param unit_to:
    :return:
    """

    return pint.Quantity(time, unit).to(unit_to)



import ast
from typing import Union


def isString(data) -> bool: return type(data) == str


def isInt(data) -> bool: return type(data) == int


def isFloat(data) -> bool: return type(data) == float


def isBytes(data) -> bool: return type(data) == bytes


def isBool(data) -> bool: return type(data) == bool


def isDictionary(data) -> bool: return type(data) == dict


def isList(data) -> bool: return type(data) == list


def isSet(data) -> bool: return type(data) == set


def isTuple(data) -> bool: return type(data) == tuple


def isJson(data) -> bool: return isDictionary(data) or isList(data) or isSet(data) or isTuple(data)


def json_to_str(json: Union[dict, list, set, tuple]) -> str: return str(json) if isJson(json) else json


def json_to_bytes(json: Union[dict, list, set, tuple]) -> bytes: return bytes(string, encoding="utf-8") if isString(string := json_to_str(json)) else string


def json_to_xml(json: dict) -> str: return "".join(["""<{tag}>{value}</{closetag}>""".format(tag=tag, value=json_to_xml(value) if isDictionary(value) else value, closetag=tag.split()[0]) for tag, value in json.items()]) if isDictionary(json) else json_to_str(json)


def str_to_bytes(string: str) -> bytes: return bytes(string, encoding="utf-8") if isString(string) else string


def str_to_json(string: str) -> Union[dict, list, set, tuple]: return ast.literal_eval(string) if isString(string) else string


def bytes_to_str(_bytes: bytes) -> str: return bytes.decode(_bytes, "utf-8") if isBytes(_bytes) else _bytes


def bytes_to_json(_bytes: bytes) -> Union[dict, list, set, tuple]: return str_to_json(bytes_to_str(_bytes)) if isBytes(_bytes) else _bytes



from typing import Union

import pint

CELSIUS = "degC"
FAHRENHEIT = "degF"
KELVIN = "kelvin"


def convert(
        temperature: Union[int, float],
        unit: Union[
            CELSIUS,
            FAHRENHEIT,
            KELVIN
        ],
        unit_to: Union[
            CELSIUS,
            FAHRENHEIT,
            KELVIN
        ]
) -> str:
    """
    Converts a temperature unit to other different unit

    :param temperature:
    :param unit:
    :param unit_to:
    :return:
    """

    return pint.Quantity(temperature, unit).to(unit_to)



from .objects import *
from .distance import convert as distance_converter
from .temperature import convert as temperature_converter
from .time import convert as time_converter

from .distance import METER, CENTIMETER, MILLIMETER, KILOMETER, INCH, HAND, FOOT, YARD, MILE, LIGHT_YEAR, ASTRONOMICAL_UNIT, PARSEC, NAUTICAL_MILE, ANGSTROM, MICRON, PLANCK_LENGTH
from .temperature import CELSIUS, FAHRENHEIT, KELVIN
from .time import SECONDS, MINUTES, HOURS, DAYS, WEEKS, FORTNIGHTS, YEARS, MONTHS, CENTURIES, MILLENNIUMS



import setuptools

with open("README.md", "r", encoding="utf-8") as fh: long_description = fh.read()

setuptools.setup(
    name="pysem-converters",
    version="0.1",
    author="Adrián Toral",
    author_email="adriantoral@sertor.es",
    description="",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/pysem/converters",
    project_urls={
        "Website": "https://github.com/pysem/converters",
        "Issues": "https://github.com/pysem/converters/issues",
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Operating System :: OS Independent",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
    packages=["pysem_converters"],
    package_dir={"": "src"},
    python_requires=">=3.8",
    keywords='python, converters, utilities, python-converters, python-converters-utilities',
)
